__code__='Gas1];/[+<&>$Qs4,sVT9RtPX\\O("MV4IuBW2ckta97BBE?bkpR9$6/bpGGk^,u&>M/s#"60_,C8H2//`kD(QnC3kaO18$*hAr_BB>/:r]\\i\\j1S8G>J#8Y49a5OO&E"--5_->Zp<\\>`!%Hh;GVT!rU]F$("LJ/EJ9AXf^]r^Z?k`#Dhu_hN^b^LR!F(*;!8E%e!>bbi!+#f@"S`;]A\\_(B56JP"GST^h^h^l/p6Ea)%t;7p^CdpY_]$TWB-8df2)mEY]`&Sq?Wur^fPSDW37T26E#f.R0+5$+bSFkm"`gHF/:u"_;?^N5a\'/R3PCF\'\'Q4i9/&\'Sal24Zl7E4J=;%Kp$a@tFnETOBS]jco]F>#[RqRADh"^ju\'+jXRd.LB9kKG*^eWq\'kcEk,gdlgjcp+i8N.F=j1_Sm;&h]\\SSjUV(.FHa""/a7[o*f$ZhPL%?6AB02N,#l!6eJEh\\j!mBUfb=^(6*.d0X:\\mlaM=a.N@7-LHDKor6;>K1Y*R\\DB;,.H-o1aRa.kJdEkH=#"k]MX:@Lt<$+pNl0r7jk<.E@\'q0R:jEs1DlS*Jf\'sN#D7ESINm6/C"M7HfA(!@43VNuNl"\'$R7\',:6kX/pfpqTeeiNc\'gYLW=F&][fq&<(jN#\\<@qeki\'m/#,^f3o<HM6c4g%2E:T8\\4q/+=<m,Mh9a^<\\I<bSEc"0AH,tR=8jTDXl_Q+-u`7fN&/pS@Ok#LqT*g0c*,G=5"5DUPU]q]n+;cFqp^tmj\'*V5UI,`=3`a)*T1Oe>=8TlkGA](iVK$P=mW\\Dk^ZWjSH2AH?ENH!orJ2(iH-sgM$:fJa9Z\'H3e,K-14^A[occo\\1[L@>rGcU*PD7_<D]BX&%5MXHgh<dAL(Z0G*"78fIN$NGjYBdH88p:!$4O;aa)2qRop[.-P&sY%p04MXtoh\'iHRE=\'^W)o^@,MiF)cH\'%LA<@c%7PnPe<12rGA^0rg_a)[&AkaeiW#\\`kaTknXW-bB%Xtl\\NVU,sU`=G=+PXq?71$<h2\'G4<$Cb]g)$agscL"IimY%!fa63!jKU@I9+^4,)2ll.QSS?L7sGu6fbHeDL8FlQh$Wb!L~>'



__code__='Gas1]gMYJ*&Daab$RN/o.")2#gk:f/HD)\'?#Q\\X*885"n+io0ba1H3E3k!_t[&I&sdT8Vc?h,^s_%SV"6Gk\\+*fYAUcKqXpp`#Xtc,4i/983H5MF1\\]7N"32N!qS!E]PHU*B`@#e!SDh<a\\?s@V\'_6c*3,-_Ci)r2TMh6rla)J4sV*.j2)&G0q8:uElnht)![?5g?=Xm`qoh<Z--du.C"RbYnf.LnY_GB:QD^d^nE;(NWpf\'n/6@j7Nn`R-obGF50bn&X+>Q^fE+44Mr_4Ia=0."R5WRVMP@Y`j&)%aW[2iVV*f)j.5VCE7Ou19hNI=#l^+`Ec&LmJQCaB8\\FPjs=\\4X566_"P=[m!o*q!Vsb4M:\\F0oiWQ&%1ps)*[T&!ZSOXkIRannMG;^HUMSpJhdIHG:DSbYCng/P3/SM0Xc?Ba(*Xkh&I9d2(4[]5H^&\\Ed`_Y1nk;5=E-C\\tAh*3:_kC8BhN<_$\'tS,n8N>au%p0?h5NYWp+ZNmH0nH)+`44_nbGtjNL:#nGC@eGGjHoPtE+Klc7&d[`CBpYA=#TcSe^Ko>h=:SdOJuN.o@Y8K`Q\'O->c73Ns:;heC"qoFj*]q!Uap\')Bk0)o$N9`.c-NW&Q[=#C6P>f;B*<B)7-nV%H5?K<EN`GQ):,!a[\\I$\\.&tgid:2QBmlq^V7@(IspuU>!(&Y)(@0^02-9h4kr,s`HodKj.8*JAm4m%\\UPGaH]qZ*CQn(P>j*c-0)W@;N&Gmn+QP)ERI%qKBs#YY^\'N5Fq)4&H]Ou$*d@[l%!3N,.!0".EitgWT\':mkX>:kLeYdsS4!G2EsbtWG$2P-]>$G#$mPU_\\oE?_r_!/#\'E*)KW6B9X30\\bJEp)CWAU)$p^A3hK$7CDQ[PVAFq:E\'Q"DdD9`GS/\'jbD-+!$OVb/s;+:.^1hX,:=ikg"0EeDGfg+Dq&1HD!)*Q4-O[+W^8UjZ1<dlmReRM:>GO\\m(B8]2n;!gKnJl\\_&p&cFm>b(~>'



__code__='Gas1]gMYJ*&Daab$Z5,SPeM]"TVt>skliPi&-C8q+f1kV/O]kS3SnUglI]]me#$/k8mhB!GiY4hb$XYVN182@;W@Ib]K:2[b\\Ca>P+gbI][,N$+TN_sGtAiag\'M1k:NIq^4lXiV$a)4T)6CW2XMi9J$6*EKClDY2j(s<AZ7/iM3q5rE:0,HVkms4m3!EXLPT.9^djb+*Z;\'0pmgJJ#Rm%ujM-Y$4CW<(dh=cVfd0Ie;!,rL(KJ\\bonIt3ON\'^W4:tTUZH9]F5^GUsS`ZjV$SKV?^7?5Kp%V=jE;:41M0c?f.CPeVNd[o$b\'ZpVdUQLSJZdRZSo;](+]!AbYkuh_e.o.UVQ"8c#,U/&/ARpPViD)k;9Q/*[7r(OXLa[oP02$u2X+Y\\HaaRnV/6/P9X8Sl07g5TfG$8n,m,TSDOp%hI(e88-NkpntgNJ`^ZiM(Vf8[F$GMR)RFk\\Y:KP6FWmcTTHT\'hCH#gJ\'Yi!KOWP(r</AX\\+HlfK.X`\'W"fQFTlMC79]14YmLo*_FZ$7"C)sb]mdADbm@nEOC+;G\\E"_1%\\YX+1H)C[9!mOYiD]*Nm(Um]UK$*B`\'hMqO7Sp^jiL&$dhPq5k/kjF5V>Ca6dr5*,m&U%i*-^i\'=K]l./[_IARB?MmYNB*`RQr1O#Np$[Bpl,Q\']#En_I=S6qY=s74%E#Koc$d`P_ZX%74BH!u"XB]Iea/aCm`KmV87S*?``a8PrZg)Z\\U=rA=+i\':pd3rS6_d+d@GJrm<\\A?[!@Vj/V\'4!IKkk1_!go9ucf7t9B3!]92&!H<q(*7keSlaXJ+YhhXtK#Q8a2)&gU;dY7IH>O,9f?!XYcb*^O\'aJf(#G?EBO\\ZZEJ1ill7-,\'f\';iSL:u4C,1@4>>\'sY;Pi%&JLS6gbPMAJVR>T[TI2]oRL-tD>T@oQ.]\'k!<5P3[F&#TPk$JV7/L:qSA9\\t@@PJb,.Rs(b*0nrqP%HA^\\P*o8/a]NCs6ec,/6CQm8pIKL;L>k7~>'
